# Tutorials

!!! info
    We aim to provide additional tutorials in the future - contributions are welcome!

- [Quickstart example](../quickstart.md): Using lakeFS-spec as a file system
- [A fully-worked data science example](demo_data_science_project.ipynb): Using lakeFS-spec together with Pandas to train a classifier based on a public dataset and simulate additional data being collected
